

===
API
===

.. contents::
    :local:

Base classes
++++++++++++

.. toctree::
    :maxdepth: 1

    model_base_sir
    optim

Models
++++++

.. toctree::
    :maxdepth: 1

    model_covidsir

scikti-learn API
++++++++++++++++

.. toctree::
    :maxdepth: 1

    model_epireg

dummy
++++++

.. autofunction:: aftercovid.tutorial.experiment_cython.pyfilter_dmax

.. autofunction:: aftercovid.tutorial.experiment_cython.filter_dmax_cython

.. autofunction:: aftercovid.tutorial.experiment_cython.filter_dmax_cython_optim

.. autofunction:: aftercovid.tutorial.experiment_cython.cyfilter_dmax

.. autofunction:: aftercovid.tutorial.experiment_cython.cfilter_dmax

.. autofunction:: aftercovid.tutorial.experiment_cython.cfilter_dmax2

.. autofunction:: aftercovid.tutorial.experiment_cython.cfilter_dmax4

.. autofunction:: aftercovid.tutorial.experiment_cython.cfilter_dmax16

